local playerClass = select(2, UnitClass("player"))
local spellID, spellName, spellTexture, tooltip, assigned

if playerClass == "ROGUE" then
	spellID = 57934 -- Tricks of the Trade
elseif playerClass == "HUNTER" then
	spellID = 34477 -- Misdirection
elseif playerClass == "SHAMAN" then
	spellID = 974 -- Earth Shield
elseif playerClass == "PRIEST" then
	spellID = 6346 -- Fearward
elseif playerClass == "WARRIOR" then
	spellID = 50720 -- Vigilance
elseif playerClass == "DEATHKNIGHT" then
	spellID = 49016 -- Hysteria
else
	return
end

local LibQTip = LibStub('LibQTip-1.0')

spellName, _, spellTexture = GetSpellInfo(spellID)

local icon = CreateFrame("Button", "EasyButton", UIParent, "SecureActionButtonTemplate")
icon.initialMacro = ""
icon.macroFormat = "/cast [@%s] "..spellName
icon.noMacro = "/s No Tank Set?"

icon:RegisterEvent("PLAYER_TALENT_UPDATE")

local function eventHandler(self, event, ...)
	if event == "PLAYER_TALENT_UPDATE" then
		if not IsUsableSpell(spellName) then
			--icon:Hide()
		else
			icon:Show()
		end
	end
end

local background = icon:CreateTexture("EasyButtonBackground", "BACKGROUND")
background:SetTexture(spellTexture)
background:SetAllPoints()

icon:SetPushedTexture('Interface\\Buttons\\UI-Quickslot-Depress')
icon:SetHighlightTexture('Interface\\Buttons\\ButtonHilight-Square')
icon:SetWidth(36)
icon:SetHeight(36)
icon:SetScale(0.78)

icon:SetClampedToScreen(true)
icon:RegisterForClicks("AnyUp")
icon:RegisterForDrag("LeftButton")
icon:SetMovable(true)
icon:SetPoint("CENTER", UIParent, "CENTER")
icon:Show()
icon:SetAttribute("type1", "macro")
icon:SetAttribute("macrotext", icon.initialMacro)
icon:SetAttribute("type2", "macro")
icon:SetAttribute("macrotext2", "/script EasyButton:CreateTip()")

local function createLine(unit)
	local y, x = tooltip:AddLine()
	if assigned == UnitName(unit) then
		tooltip:SetCell(y, 1, "|TInterface\\Buttons\\UI-CheckBox-Check:20:20|t")
	else
		tooltip:SetCell(y, 1, "|TInterface\\Buttons\\UI-CheckBox-UP:20:20|t")
	end
	
	if UnitInRaid("player") then
		if GetPartyAssignment("MAINTANK", unit) then
			tooltip:SetCell(y, 2, "|TInterface\\GroupFrame\\UI-Group-MainTankIcon:0|t")
		elseif GetPartyAssignment("MAINASSIST", unit) then
			tooltip:SetCell(y, 2, "|TInterface\\GroupFrame\\UI-Group-MainAssistIcon:0|t")
		else
			tooltip:SetCell(y, 2, "")
		end
	else
		isTank, isHealer, isDPS = UnitGroupRolesAssigned(unit)
		if isTank then
			tooltip:SetCell(y, 2, "|TInterface\\LFGFrame\\UI-LFG-ICON-PORTRAITROLES.blp:20:20:0:0:64:64:0:19:22:41|t")
		elseif isHealer then
			tooltip:SetCell(y, 2, "|TInterface\\LFGFrame\\UI-LFG-ICON-PORTRAITROLES.blp:20:20:0:0:64:64:20:39:1:20|t")
		elseif isDPS then
			tooltip:SetCell(y, 2, "|TInterface\\LFGFrame\\UI-LFG-ICON-PORTRAITROLES.blp:20:20:0:0:64:64:20:39:22:41|t")
		else
			tooltip:SetCell(y, 2, "")
		end
	end

	local c = RAID_CLASS_COLORS[select(2, UnitClass(unit))]
	tooltip:SetCell(y, 3, format("|cff%02x%02x%02x%s|r",c.r*255,c.g*255,c.b*255,UnitName(unit)))
	tooltip:SetLineScript(y, "OnMouseUp", function()
		assigned = UnitName(unit)
		print(spellName.." will be placed on "..assigned)
		icon:SetAttribute("macrotext",  icon.macroFormat and icon.macroFormat:format(unit) or icon.noMacro)
		tooltip:Hide()
	end)
end

function icon:CreateTip()
	if GetNumPartyMembers() == 0 and not UnitInRaid("player") then
		assigned = UnitName("player")
		icon:SetAttribute("macrotext", icon.macroFormat and icon.macroFormat:format("player") or icon.noMacro)
		--return
	end
	if tooltip then
		LibQTip:Release(tooltip)
	end
	
	tooltip = LibQTip:Acquire("EasyButtonTooltip", 3, "CENTER", "CENTER", "LEFT")
	tooltip:Clear()
	icon.tooltip = tooltip
	if UnitInRaid("player") then
		for i = 1, 40 do
			if UnitIsPlayer("raid"..i) then createLine("raid"..i) end
		end
	else
		for i = 1, 4 do
			if UnitIsPlayer("party"..i) then createLine("party"..i) end
		end
		createLine("player")
	end
	tooltip:SetAutoHideDelay(0.01, icon)
	tooltip:SmartAnchorTo(icon)
--	tooltip:SetScale(.5)
	tooltip:Show()
end

icon:SetScript("OnEvent", eventHandler)

icon:SetScript("OnDragStart", function()
	if IsShiftKeyDown() then
		icon:StartMoving()
	end
end)

icon:SetScript("OnDragStop", function()
	icon:StopMovingOrSizing()
end)

